<img src="https://exaworks.org/images/exaworks-psij-logo.png" width="300" style="margin-bottom: 2em"/>

# Portable Submission Interface for Jobs

PSI/J is an abstraction layer over cluster schedulers to write scheduler
agnostic HPC applications. PSI/J automatically translates abstract job
specifications into concrete scripts and commands to send to the
scheduler. PSI/J is tested on a wide variety of clusters. For further
information about [PSI/J](https://exaworks.org/job-api-spec/) or the
[SDK](https://github.com/ExaWorks/SDK) visit the
[ExaWorks](https://exaworks.org/) project page and read the [PSI/J
documentation](https://exaworks.org/psij-python/#docs).


## Introduction

1. [Quick start guide](QuickStart.md)
2. [Workflow examples](scripts/WORKFLOW-EXAMPLES.md)
3. [Setting up tests](README-testing.md)
4. [How to contribute](CONTRIBUTING.md)
5. [Building the documentation](README-dev.md)
